b2luigi
=======

``b2luigi`` is a helper package constructed around ``luigi``, that helps you schedule working packages (so called tasks)
locally or on the batch system.
Apart from the very powerful dependency management system by ``luigi``, ``b2luigi`` extends the user interface
and has a build-in support for the queue systems, e.g. LSF.

You can find more information in the `documentation <https://b2luigi.readthedocs.io/en/latest/>`_.

Please note, that most of the core features are handled by ``luigi``, so you might want to have a look into
the `luigi documentation <https://luigi.readthedocs.io/en/latest/>`_.

If you find any bugs or want to improve the documentation, please send me a pull request.

This project is in beta. Please be extra cautious when using in production mode.
